summaryrefslogtreecommitdiff
path: root/png.h
diff options
context:
space:
mode:
authorGlenn Randers-Pehrson <glennrp at users.sourceforge.net>2006-03-10 10:19:04 -0600
committerGlenn Randers-Pehrson <glennrp at users.sourceforge.net>2009-04-06 16:08:42 -0500
commit170b70ce30593998d179a53c35e981a7bccd02c6 (patch)
tree917d68e7b67c1ac3d0ba099e59ed1ba607eac3dc /png.h
parent1ce0836b4a9c1fe453a93d323ca0b806564d559e (diff)
downloadlibpng-170b70ce30593998d179a53c35e981a7bccd02c6.tar.gz
Imported from libpng-1.2.9beta9.tarv1.2.9beta9
Diffstat (limited to 'png.h')
-rw-r--r--png.h20
1 files changed, 10 insertions, 10 deletions
diff --git a/png.h b/png.h
index bc2e4bd69..46ff5e6a5 100644
--- a/png.h
+++ b/png.h
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
* libpng version 1.2.9beta8 - March 9, 2006
* Copyright (c) 1998-2006 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
@@ -9,7 +9,7 @@
* Authors and maintainers:
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
* libpng versions 0.97, January 1998, through 1.2.9beta8 - March 9, 2006: Glenn
* See also "Contributing Authors", below.
*
* Note about libpng version numbers:
@@ -113,7 +113,7 @@
* 1.0.18 10 10018 12.so.0.1.0.18
* 1.2.8 13 10208 12.so.0.1.2.8
* 1.2.9beta1-3 13 10209 12.so.0.1.2.9beta1-3
- * 1.2.9beta4-8 13 10209 12.so.0.9[.0]
+ * 1.2.9beta4-10 13 10209 12.so.0.9[.0]
*
* Henceforth the source version will match the shared-library major
* and minor numbers; the shared-library major version number will be
@@ -143,7 +143,7 @@
* If you modify libpng you may insert additional notices immediately following
* this sentence.
*
* libpng versions 1.2.6, August 15, 2004, through 1.2.9beta8, March 9, 2006, are
* Copyright (c) 2004, 2006 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.2.5
* with the following individual added to the list of Contributing Authors:
@@ -255,13 +255,13 @@
* Y2K compliance in libpng:
* =========================
*
- * March 9, 2006
+ * March 10, 2006
*
* Since the PNG Development group is an ad-hoc body, we can't make
* an official declaration.
*
* This is your unofficial assurance that libpng from version 0.71 and
* upward through 1.2.9beta8 are Y2K compliant. It is my belief that earlier
* versions were also Y2K compliant.
*
* Libpng only has three year fields. One is a 2-byte unsigned integer
@@ -317,9 +317,9 @@
*/
/* Version information for png.h - this should match the version in png.c */
-#define PNG_LIBPNG_VER_STRING "1.2.9beta8"
+#define PNG_LIBPNG_VER_STRING "1.2.9beta9"
#define PNG_HEADER_VERSION_STRING \
- " libpng version 1.2.9beta8 - March 9, 2006 (header)\n"
+ " libpng version 1.2.9beta9 - March 10, 2006 (header)\n"
#define PNG_LIBPNG_VER_SONUM 0
#define PNG_LIBPNG_VER_DLLNUM 13
@@ -331,7 +331,7 @@
/* This should match the numeric part of the final component of
* PNG_LIBPNG_VER_STRING, omitting any leading zero: */
-#define PNG_LIBPNG_VER_BUILD 8
+#define PNG_LIBPNG_VER_BUILD 9
/* Release Status */
#define PNG_LIBPNG_BUILD_ALPHA 1
@@ -1361,7 +1361,7 @@ struct png_struct_def
/* This triggers a compiler error in png.c, if png.c and png.h
* do not agree upon the version number.
*/
-typedef png_structp version_1_2_9beta8;
+typedef png_structp version_1_2_9beta9;
typedef png_struct FAR * FAR * png_structpp;
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
- * libpng version 1.2.9beta8 - March 9, 2006
+ * libpng version 1.2.9beta9 - March 10, 2006
* Copyright (c) 1998-2006 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
@@ -9,7 +9,7 @@
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
- * libpng versions 0.97, January 1998, through 1.2.9beta8 - March 9, 2006: Glenn
+ * libpng versions 0.97, January 1998, through 1.2.9beta9 - March 10, 2006: Glenn
* See also "Contributing Authors", below.
*
@@ -143,7 +143,7 @@
* this sentence.
*
- * libpng versions 1.2.6, August 15, 2004, through 1.2.9beta8, March 9, 2006, are
+ * libpng versions 1.2.6, August 15, 2004, through 1.2.9beta9, March 10, 2006, are
* Copyright (c) 2004, 2006 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.2.5
@@ -255,13 +255,13 @@
*
* This is your unofficial assurance that libpng from version 0.71 and
- * upward through 1.2.9beta8 are Y2K compliant. It is my belief that earlier
+ * upward through 1.2.9beta9 are Y2K compliant. It is my belief that earlier
* versions were also Y2K compliant.
*